@@ -24,10 +24,10 @@
 #include <config.h>
 
 #include <string.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
 #include "baobab.h"
@@ -63,12 +63,15 @@ props_notify (GConfClient *client,
 	      GConfEntry *entry,
 	      gpointer user_data)
 {
-	g_slist_foreach (baobab.bbExcludedDirs, (GFunc) g_free, NULL);
-	g_slist_free (baobab.bbExcludedDirs);
+	GSList *uris;
 
-	baobab.bbExcludedDirs =
-	    gconf_client_get_list (client, PROPS_SCAN_KEY,
-				   GCONF_VALUE_STRING, NULL);
+	uris = 	gconf_client_get_list (client,
+				       PROPS_SCAN_KEY,
+				       GCONF_VALUE_STRING,
+				       NULL);
+	baobab_set_excluded_locations (uris);
+	g_slist_foreach (uris, (GFunc) g_free, NULL);
+	g_slist_free (uris);
 
 	baobab_get_filesystem (&g_fs);
 	set_label_scan (&g_fs);
@@ -85,7 +88,7 @@ filechooser_response_cb (GtkDialog *dialog,
 	switch (response_id) {
 		case GTK_RESPONSE_HELP:
 			baobab_help_display (GTK_WINDOW (baobab.window), 
-			                     "baobab.xml", NULL);
+			                     "baobab.xml", "baobab-preferences");
 			break;
 		case GTK_RESPONSE_CLOSE:
 			if (props_changed) { 
@@ -142,10 +145,11 @@ create_props_model (void)
 	mdl = gtk_list_store_new (TOT_COLUMNS,
 				  G_TYPE_BOOLEAN,	/* checkbox */
 				  G_TYPE_STRING,	/* device */
-				  G_TYPE_STRING,	/* mount point */
+				  G_TYPE_STRING,	/*mount point display */
+				  G_TYPE_STRING,	/* mount point uri */
 				  G_TYPE_STRING,	/* fs type */
 				  G_TYPE_STRING,	/* fs size */
-				  G_TYPE_STRING		/* fs used */
+				  G_TYPE_STRING		/* fs avail */
 				  );
 
 	return mdl;
@@ -182,8 +186,8 @@ create_tree_props (GladeXML *dlg_xml)
 	cell = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (_("Mount Point"),
 							cell, "markup",
-							COL_MOUNT, "text",
-							COL_MOUNT, NULL);
+							COL_MOUNT_D, "text",
+							COL_MOUNT_D, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tvw), col);
 
 	/* third text column */
@@ -234,7 +238,7 @@ check_toggled (GtkCellRendererToggle *cell,
 	gtk_tree_model_get_iter ((GtkTreeModel *) model_props, &iter,
 				 path);
 	gtk_tree_model_get ((GtkTreeModel *) model_props, &iter, COL_CHECK,
-			    &toggle, COL_MOUNT, &mountpoint, -1);
+			    &toggle, COL_MOUNT_D, &mountpoint, -1);
 
 	/* check if root dir */
 	if (strcmp ("/", mountpoint) == 0)
@@ -267,22 +271,34 @@ fill_props_model (GtkWidget *dlg)
 	     
 	     	glibtop_fsusage fsusage;
 		gchar * total, *avail;
+		GFile	*file;
+		gchar	*uri;
+		
+                struct stat buf;
+                if (g_stat(mountentry->devname,&buf) == -1)
+                  continue;		
+				
 		glibtop_get_fsusage (&fsusage, mountentry->mountdir);
 		fstotal = fsusage.blocks * fsusage.block_size;
 		fsavail = fsusage.bfree * fsusage.block_size;
-		total = gnome_vfs_format_file_size_for_display(fstotal);
-		avail = gnome_vfs_format_file_size_for_display(fsavail);
+		total = g_format_size_for_display(fstotal);
+		avail = g_format_size_for_display(fsavail);
+		file = g_file_new_for_path (mountentry->mountdir);
+		uri = g_file_get_uri (file);
 		gtk_list_store_append (model_props, &iter);
 			gtk_list_store_set (model_props, &iter,
 					    COL_CHECK, TRUE,
-					    COL_DEVICE, mountentry->devname, 
-					    COL_MOUNT, mountentry->mountdir, 
+					    COL_DEVICE, mountentry->devname,
+					    COL_MOUNT_D, mountentry->mountdir, 
+					    COL_MOUNT, uri, 
 					    COL_TYPE, mountentry->type,
 					    COL_FS_SIZE, total,
 					    COL_FS_AVAIL, avail,
 					    -1);
 		g_free(total);
 		g_free(avail);
+		g_free(uri);
+		g_object_unref(file);
 	}
 
 	g_free (mountentry_tofree);
@@ -345,6 +361,23 @@ set_gconf_list (GtkTreeModel *model,
 	return FALSE;
 }
 
+static gint
+list_find (gconstpointer a, gconstpointer b)
+{
+	gchar *str_a, *str_b;
+	gint ret;
+	
+	str_a = g_uri_unescape_string (a,NULL);
+	str_b = g_uri_unescape_string (b,NULL);
+
+	ret = strcmp (str_a, str_b);
+
+	g_free (str_a);
+	g_free (str_b);
+
+	return ret;
+}
+
 gboolean
 set_model_checks (GtkTreeModel *model,
 		  GtkTreePath *path,
