@@ -28,7 +28,6 @@
 
 #include <config.h>
 #include "baobab-remote-connect-dialog.h"
-#include "baobab-mount-operation.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -128,13 +127,14 @@ connect_server_dialog_present_uri (GtkWindow *app,
 {
 	GMountOperation *op;
 
-	op = baobab_mount_operation_new (GTK_WINDOW (widget));
+	op = gtk_mount_operation_new (GTK_WINDOW (widget));
 
 	g_file_mount_enclosing_volume (location,
 				       0, op,
 				       NULL,
 				       (GAsyncReadyCallback) mount_enclosing_ready_cb,
 				       app);
+	g_object_unref (op);
 }
 
 struct MethodInfo {
